package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.34.1 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.34.1) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@$!`0````````````,`*``!````A10``#0```!0@0````0`!30`(``'
M`"@`%@`5``8````T````-````#0```#@````X`````0````$`````P```!0!
M```4`0``%`$``!@````8````!`````$````!````````````````````I'``
M`*1P```%```````!``$```#,?0``S'T!`,Q]`0!P`@``G!(```8```````$`
M`@```-1]``#4?0$`U'T!`/````#P````!@````0```!1Y71D````````````
M```````````````&````$````%+E=&3,?0``S'T!`,Q]`0`T`@``-`(```0`
M```!````+VQI8B]L9"UM=7-L+6%R;6AF+G-O+C$`$0```$P````(````"```
M``&0$``E0`2`*(`0!:"&4(2``0``"R`$C3B`$D&*!`@(3````$T```!1````
M5@```%<```!>````7P```&``````````8@```&,`````````9````&4```!H
M```````````````!KS3H:G^:?.K3[P[.WD<M;\7?'R[%F[:XC?$.U&34?'94
M/)0A_^0.V7%8'/JA;&#"Y3\LL@&+;T+ZUX?B1\8!6.^7>;OCDGQ5PSS29Z_,
M9H@'<--#1=7L,V+;[16,)<Q_J9R;X*<""FH:GE"_VE<;H^#[20``````````
M````````````````#!`````````#``<```````"``0```````P`1``$`````
M`````````!(````)```````````````1````[`$`````````````$0```(@!
M`````````````!(````0```````````````2````Q0$`````````````$@``
M`!@``````````````!(````?```````````````2````^0$`````````````
M$@```-$!`````````````!(````H```````````````@````'P,`````````
M````(0```$```````````````!(```!&```````````````2````30``````
M````````$@```.P"`````````````!(```#=`@`````````````2````5```
M````````````$@```#8"`````````````!(```!;```````````````2````
MO`(`````````````$@```&(``````````````!(```!J```````````````2
M````I0(`````````````$@```'(``````````````!(```![````````````
M```@````U@(`````````````$@```)<``````````````!(```"<````````
M```````2````"@(`````````````$0```,,"`````````````!(```!C`@``
M```````````2````HP``````````````$@```%4"`````````````!(```!C
M`P`````````````2````'@,`````````````$0```(<"`````````````!(`
M```+`P`````````````2````%0(`````````````$@```"`#````````````
M`!$```"J```````````````2`````P,`````````````$@```+,`````````
M`````!$```"6`0`````````````2````Q0``````````````(@```-0`````
M`````````"````#J```````````````2````S@(`````````````$@```',"
M`````````````!(```#O```````````````2````]0``````````````(```
M`+`"`````````````!(````/`0`````````````2````M@$`````````````
M$@```!0!`````````````!(```"5`@`````````````2````&@$`````````
M````$@```*4!`````````````!(````H`0`````````````2````.0$`````
M````````$@```#$"`````````````!(```!"`@`````````````2````/P$`
M````````````$@```'P"`````````````!(```#\`@`````````````2````
M3@$`````````````$@```/0"`````````````!(```!B`0`````````````2
M````+`(`````````````$@```&D!`````````````!(```!P`0``````````
M```2````'0,`````````````(0```($!`````````````!(```!C!```:)`!
M```````0`!(`&`,```43``"``0``$@`)`.8!``!!,````@```!(`"@"E`P``
M/1\``,P$```2``D`<P0``)TE```X````$@`)`((#``#1&@``!````!(`"0`7
M!```#1````(````2``<`R`,```DD``"4`0``$@`)`!T$```\@`$``````!``
M$@!+!```U1H``'0!```2``D```0``#R``0``````$``2`),#``#1'@``;```
M`!(`"0"R`P``?1D``#@````2``D`N@,``($>``!`````$@`)`-X#``#%+@``
MP@```!(`"0#S`P``21P``!(````2``D`#`0``&B0`0``````$``2`&X$``!H
MD`$``````!``$@!(`P``H10``#@````2``D`*P0``%L<``">````$@`)`.D#
M```X@`$`!````!$`$0!$!```/(`!```````0`!$`!00``(44````````$@`)
M`!0$``")+@``/````!(`"0!1`P``P1X``!`````2``D`;`,``/T9``#4````
M$@`)`%@$``"'+P``N````!(`"0!B!```:)`!```````0`!(`-P0``/D<``"(
M`0``$@`)``!O<&5N9&ER`'-T9&5R<@!R96%L;&]C`&%C8V5S<P!S;G!R:6YT
M9@!?7V1E<F5G:7-T97)?9G)A;65?:6YF;P!L<V5E:P!G971P:60`<W1R8VUP
M`&UE;7-E=`!U;FQI;FL`;65M;6]V90!S=')N8VUP`&-L;W-E9&ER`%])5$U?
M9&5R96=I<W1E<E1-0VQO;F5486)L90!O<&5N`'-T<G-T<@!S=')C:'(`<F5A
M9&QI;FL`7U]S=&%C:U]C:&M?9W5A<F0`7U]C>&%?9FEN86QI>F4`7U]R96=I
M<W1E<E]F<F%M95]I;F9O`&5X:70`8VQO<V4`7TE435]R96=I<W1E<E1-0VQO
M;F5486)L90!R96%D`')M9&ER`%]?<W1A=%]T:6UE-C0`7U]E<G)N;U]L;V-A
M=&EO;@!M:V1I<@!?7VQS=&%T7W1I;64V-`!P=&AR96%D7V=E='-P96-I9FEC
M`&UE;6-P>0!S=')L96X`7U]S=&%C:U]C:&M?9F%I;`!G971U:60`4&5R;%]S
M>7-?=&5R;0!097)L7W-Y<U]I;FET,P!097)L7V%T9F]R:U]L;V-K`'!E<FQ?
M8V]N<W1R=6-T`%!E<FQ?9V5T7W-V`%!E<FQ?8W)O86M?;F]C;VYT97AT`%]F
M:6YI`%!,7V1O7W5N9'5M<`!097)L7VYE=UA37V9L86=S`%!,7W1H<E]K97D`
M4&5R;%]C<F]A:U]M96UO<GE?=W)A<`!P97)L7V9R964`4&5R;%]M9U]S970`
M4&5R;%]A=&9O<FM?=6YL;V-K`%!E<FQ?<W9?<V5T<'8`4&5R;%]G=E]F971C
M:'!V`'!E<FQ?<G5N`%!E<FQ?;F5W6%,`<&5R;%]D97-T<G5C=`!B;V]T7T1Y
M;F%,;V%D97(`<&5R;%]P87)S90!097)L7W-A9F5S>7-M86QL;V,`<&5R;%]A
M;&QO8P!F<')I;G1F`'-T<F1U<`!P=&AR96%D7V%T9F]R:P!R96%D9&ER`'-P
M<FEN=&8`<W1R=&]K`'-T<FYC<'D`7U]L:6)C7W-T87)T7VUA:6X`7U]?96YV
M:7)O;@!L:6)P97)L+G-O`&QI8F,N;75S;"UA<FUV-RYS;RXQ`%]S=&%R=%]C
M`&=E=%]U<V5R;F%M95]F<F]M7V=E='!W=6ED`'!A<E]C=7)R96YT7V5X96-?
M<')O8P!P87)?8W5R<F5N=%]E>&5C`'!A<E]S971U<%]L:6)P871H`'!A<E]M
M:W1M<&1I<@!X<U]I;FET`'!A<E]E;G9?8VQE86X`6%-?26YT97)N86QS7U!!
M4E]"3T]4`'-H85]U<&1A=&4`;7E?<&%R7W!L`'!A<E]B87-E;F%M90!?7V)S
M<U]S=&%R=`!?7V5N9%]?`'-H85]I;FET`%]?8G-S7W-T87)T7U\`<&%R7V1I
M<FYA;64`<&%R7VEN:71?96YV`%]E9&%T80!P87)?9FEN9'!R;V<`<VAA7V9I
M;F%L`%]?8G-S7V5N9%]?`%]E;F0`<&%R7V-L96%N=7``+W5S<B]L:6(O<&5R
M;#4O8V]R95]P97)L+T-/4D4`````S'T!`!<```#0?0$`%P```,!_`0`7````
MS'\!`!<```#8?P$`%P````"``0`7````"(`!`!<````,@`$`%P```!2``0`7
M````&(`!`!<````<@`$`%P```""``0`7````)(`!`!<````L@`$`%P```#"`
M`0`7````.(`!`!<```#$?P$`%00``,A_`0`5!0``T'\!`!4-``#4?P$`%1P`
M`-Q_`0`5(```X'\!`!4J``#D?P$`%2T``.A_`0`5+P``['\!`!4P``#P?P$`
M%34``/1_`0`5.@``^'\!`!4\``#\?P$`%4```-!^`0`6`P``U'X!`!8&``#8
M?@$`%@<``-Q^`0`6"```X'X!`!8)``#D?@$`%@H``.A^`0`6"P``['X!`!8,
M``#P?@$`%@T``/1^`0`6#P``^'X!`!80``#\?@$`%A$```!_`0`6$@``!'\!
M`!83```(?P$`%A0```Q_`0`6%0``$'\!`!86```4?P$`%A<``!A_`0`6&```
M''\!`!89```@?P$`%AH``"1_`0`6&P``*'\!`!8=```L?P$`%AX``#!_`0`6
M'P``-'\!`!8A```X?P$`%B(``#Q_`0`6(P``0'\!`!8D``!$?P$`%B4``$A_
M`0`6)P``3'\!`!8H``!0?P$`%BD``%1_`0`6*P``6'\!`!8L``!<?P$`%BX`
M`&!_`0`6+P``9'\!`!8P``!H?P$`%C$``&Q_`0`6,@``<'\!`!8S``!T?P$`
M%C0``'A_`0`6-@``?'\!`!8W``"`?P$`%C@``(1_`0`6.0``B'\!`!8[``",
M?P$`%CT``)!_`0`6/@``E'\!`!8_``"8?P$`%D$``)Q_`0`60@``H'\!`!9#
M``"D?P$`%D0``*A_`0`610``K'\!`!9&``"P?P$`%D<``+1_`0`62```N'\!
M`!9)``"\?P$`%DL```&UO>@!0'!'!.`MY03@G^4.X(_@"/"^Y:!N`0``QH_B
M%LJ,XJ#^O.4`QH_B%LJ,XIC^O.4`QH_B%LJ,XI#^O.4`QH_B%LJ,XHC^O.4`
MQH_B%LJ,XH#^O.4`QH_B%LJ,XGC^O.4`QH_B%LJ,XG#^O.4`QH_B%LJ,XFC^
MO.4`QH_B%LJ,XF#^O.4`QH_B%LJ,XEC^O.4`QH_B%LJ,XE#^O.4`QH_B%LJ,
MXDC^O.4`QH_B%LJ,XD#^O.4`QH_B%LJ,XCC^O.4`QH_B%LJ,XC#^O.4`QH_B
M%LJ,XBC^O.4`QH_B%LJ,XB#^O.4`QH_B%LJ,XAC^O.4`QH_B%LJ,XA#^O.4`
MQH_B%LJ,X@C^O.4`QH_B%LJ,X@#^O.4`QH_B%LJ,XOC]O.5X1_WG`,:/XA;*
MC.+L_;SE`,:/XA;*C.+D_;SE`,:/XA;*C.+<_;SE`,:/XA;*C.+4_;SE`,:/
MXA;*C.+,_;SE`,:/XA;*C.+$_;SE`,:/XA;*C.*\_;SE`,:/XA;*C.*T_;SE
M`,:/XA;*C.*L_;SE`,:/XA;*C.*D_;SE`,:/XA;*C.*<_;SE`,:/XA;*C.*4
M_;SE`,:/XA;*C.*,_;SE`,:/XA;*C.*$_;SE`,:/XA;*C.)\_;SE`,:/XA;*
MC.)T_;SE`,:/XA;*C.)L_;SE`,:/XA;*C.)D_;SE`,:/XA;*C.)<_;SE`,:/
MXA;*C.)4_;SE`,:/XA;*C.),_;SE`,:/XA;*C.)$_;SE`,:/XA;*C.(\_;SE
M`,:/XA;*C.(T_;SE`,:/XA;*C.(L_;SE`,:/XA;*C.(D_;SE`,:/XA;*C.(<
M_;SE>$?]YP#&C^(6RHSB$/V\Y0#&C^(6RHSB"/V\Y7A'_><`QH_B%LJ,XOS\
MO.4`QH_B%LJ,XO3\O.4`QH_B%LJ,XNS\O.4`QH_B%LJ,XN3\O.4`QH_B%LJ,
MXMS\O.4`QH_B%LJ,XM3\O.4`QH_B%LJ,XLS\O.4`QH_B%LJ,XL3\O.4`QH_B
M%LJ,XKS\O.5PM8:PS>D$$`.2!*D#J@6H2DS_]USO2DM\1.)824L11N!8__?.
M[DA+XU@=>$=+Y%A]N?_W$.]&2GI$T&`0N0$@__=6[__W>.\@:/_WL.^`^'M7
M(&C_]ZKOD/C.,T/P`@.`^,XS(&C_]Z+OD/C.,T/P`0.`^,XS!9C"'`0PL/&`
M3P'3__<2[X```I+_]TKO,4D$G'E$2&`A:`-&`6`N20*:>41!8"U)`_$0!7E$
M"6B!8"M)>43!8`$A!9B(0CC<`"@`\0,!3^J!`4_P``#8OQ`A)$U84"1)`)!]
M1.AH>43_]YKN!$88N>AH__<.[P1&'TU]1.AH__?,[AU(>$0`\!3Y8+FK:".Y
M&TAX1`#P#?FH8!E+>T28:`BQ`?"^^!=+>T38:/_W5N__]P3N($8&L'"]5/@A
M8`$Q1?@$:[[GI&L!`#@!```T`0``!`$``!@!```8;0$`OFP!`,$?``"&;`$`
MLA\``'AL`0#1!0``8&P!`&L=```2'0``/FP!`#)L`0!/\``+3_``#@-)>41H
M1B#P#PSE1@#P`OA":0$`$[4)2@E)>D146``A"$O36`&1"$E26`"2`6@"'2!&
M__=P[@*P$+T`OQIJ`0#\````%`$```@!```&2`=+!TIX1'M$@T)Z1`/0!4O3
M6`.Q&$=P1P"_6FL!`%AK`0#<:0$`$`$```A("4MX1'M$&QK9#P=*`>NC`4D0
M>D0#T`5+TU@#L1A'<$<`OS!K`0`N:P$`J&D!`"P!```.2Q"U>T0.3!MX?$2C
MN0U+XU@CL0Q+>T08:/_W1.[_][__"DOC6!NQ"4AX1/_WD.T!(@A+>T0:<!"]
M`+_\:@$`?FD!`"0!``"N:@$`#`$``#I;``#,:@$`"+4'2P=*>T2;6"NQ!DD'
M2'E$>$3_]R#NO>@(0*KG`+\J:0$`*`$``)QJ`0#Z6@``&$LMZ?!'>T2*1@5&
M0+,62IM8'&@,LP-&'D83^`$K.KFA1G8;R$99^`1[)[D\1A3@/2KUT/#G,D8I
M1CA&__>&[0`H[]&[73TK[-&HZP0(3^JH`P$VRO@`,+P9($:]Z/"'!$;ZY_IH
M`0`<`0``![4-2@U+>D336&E&&V@!DT_P``/_][[_"4H(2WI$TU@::`&;6D!/
M\``#`=#_]TCN`[!=^`3[`+^.:`$`(`$``'AH`0!SM15*%4MZ1--8!$8;:`&3
M3_```VU&$DY^1"E&($;_]Y?_6+D/2@U+>D336!IH`9M:0$_P``,-T/_W(.X*
M2P":\U@;:`/K@@-::$/X!"L`*OK1XN<"L'"]2F@!`"`!```X:`$`*&@!`!P!
M```MZ?!',THT2WI$TUBHL!MH)Y-/\``#!4;`L0-XL['_]Y;L!D:0L2U/W_BT
M@-_XM)!_1/A$^40P1O_WT.P$1HBY,$;_]P+M*$;_]Y#M)DHB2WI$TU@::">;
M6D!/\``#-=#_]];M$S0Y1B!&__>R[``HX=!!1B!&__>L[``HV]`H1O_WP.V"
M1B!&__>\[5!$`C#_]\+L@D8C1BI&24;_]Z#M:4901O_W:.T!,%!&"]`$FP/T
M<$.S]8!/!='_]Z'_4$;_]V[MM^?_]Z+L^.<HL+WH\(<`O]QG`0`@`0``R1D`
M`,89``#'&0``E&<!`!"U%TH72WI$J+#36&E&!$8;:">33_```__W4NW8N02;
M`_1P0[/U@$\"T+/U($\&T0(A($;_]RSLL/J`\$`)"DH(2WI$TU@::">;6D!/
M\``#`]#_]VCM`"#QYRBP$+T`O_)F`0`@`0``MF8!`"WI\$\-1DI*2DMZ1--8
MA;`;:`.33_```PMX!D8]*PB_`34H1O_W0NT"J0=&,$;_]ZW^W_@$D01&^42P
ML?_W-NV'0C/8`3P5^`$[!/@!/P`K^=$Z2C=+>D336!IH`YM:0$_P``-@T/_W
M*.TU2UGX`Z#:^`"P6_@D,``K0M$Q2P3Q`@A[1!IH3^J("``J.]!!1EA&__>\
MZ\KX````*-G0`"+:^``P`I1#1$/X!"PS1AA&$_@!*PJQ/2KYT2%+@!M9^`-`
M`C<X1-WX"(#4^`"0__?XZTGX*```*+O0(VA3^"@@%O@!&Q-&$7`!,@FQ/2GW
MT3TB&G`5^`$K`_@!+P`J^=&GYP$TMN<!(D!&&F#_]]CK`9``*)W064:H\0@"
M__?6ZP&;RO@`,+KG!;"]Z/"/`+^"9@$`(`$``%1F`0`V9@$`'`$``)YG`0`0
MM0A,"$M\1.-8&&C_]Y+L!DL'2>)8O>@00`9+>41[1/_W>KP^90$`&`$``#`!
M``!%%P``1E8``!.U#$L,2GM$G%@@:/_W=NS_]]K_(&C_]W+L`"('2PA)>T3-
MZ0`R!TIY1'I$__=&ZP*P$+T&90$`&`$``)`9```=%P``)PH``#"U+THO2ZWU
M`%V'L'I$TU@-]0!1%#$;:`M@3_```__W0NLI2@.L>D0`DBA*`T9!\@$!($9Z
M1/_W&.M#'`_1`",C22!*>40-]0!0BE@4,!%H`FA10$_P``(MT/_W2NRP]8!?
M`-G_W@WU@%40-2!&3_2`4BE&__>BZP0>X-M@'/_W/.L#1@`HVM"H0@+2`AF5
M0NC3JT("V2H9DT+CTT'R`0*40M_<(D881BE&__<0[``B`T8"5<3G&$8-]0!=
M![`PO;AD`0`@`0``^!8``-X6``"`9`$`__>4ORWI\$]/2JWUA5U/2X6P>D0$
M1DY(TU@-1@WUA5%X1`PQ&V@+8$_P``/_]Y;]+R$&1B!&__<TZYBQ14@A1GA$
M__>/_D1*0$MZ1`WUA5'36`PQ&F@+:%I`3_```VS0__?<ZR!&__?4ZX-&*$;_
M]_KJ.DG?^.B0>43_]ZSK!T8X2]_XY*![1/E$^D0#DP`OU-`Z>``J"+]/1E:Q
M.48P1O_WG.HHN3%)>43_]Y3K!T;MYSA&__>LZP`E.$3!&Q#X`2TO*AC0"_$!
M`@I$LO6`7[3:`YL-\;`(J/$$!0"34D8[1D_T@%$H1@&4__=4Z@$PL/6`7P+9
M_]X%<-_G*$8$J?_W0.NHN5CXD#P#]'!#L_4`3P[1`2$H1O_W-NI(N11(*49X
M1/_W'OXH1O_WG.H$1HGG$$D`('E$M^<@1@WUA5T%L+WH\(\`O]YC`0`@`0``
M+A8``!<6``"F8P$`[!4``'T5``#@%0``LQ8``+P5```U%0``+A4```-&$_@!
M*P*Y<$<O*@B_&$;WYQ"U!$8(L0-X*[D@2'A$O>@00/_W8+K_]S;K`3@@1(1"
M`T8>TAIX`3@O*OC0G$(8TAI&$O@!&2\I$=$!.YQ"&D8#TA%X`3LO*?C0$AN3
M'+/U@%\9V`$RLO6`7PW9_]X31N3GG$+IT2-X+RL"T0E(>$3-YPA(>$3*YPA(
M(49X1`1&__=TZB!&$+T`(/SG`+]O%```#10``&@4``".8P$`,+5'2D=+>D2+
ML--8:D9&21MH"9-/\``#>40!\0H#`?$J!!5&&&A9:`@S`\6C0BI&]]$;B#U(
M*X!X1/_WG?P\2#Q,>$3_]YC\.TA\1'A$__>3_#I(>$3_]X_\.4AX1/_WB_PX
M2'A$__>'_#=(>$3_]X/\-DAX1/_W?_P@1O_W?/PS2'A$__=X_#)(>$3_]W3\
M,4AX1/_W3OP!1A"Q($;_]TW]+DAX1/_W1?P!1ABQ+$AX1/_W0_TK2'A$__<[
M_`%&J+$I2'A$__<Y_2A)*$AY1'A$__<S_2=*$DMZ1--8&F@)FUI`3_```QC0
M__>$ZB)(>$3_]Q_\`480L2!(>$3BYQ])"B)Y1`WQ$0#_]X3I`"C;T1Q(#?$;
M`7A$U.<+L#"]PF$!`"`!``#04@``"!0```<4```]%```!10```84```%%```
M#10``+H3```)%```#Q0``*43```)%```"!0```X4```1%```8A,``"<4``"1
M$P``[F`!`.D3``"!$P``YA,``&43```(M0M+>T0;:`$S#-$)2'A$__?,^R"Q
M`'@0L3`X&+\!(`5+>T088`5+>T08:`B]`+]\80$`YQ(``%YA`0!880$`"+7_
M]QKJ__=@Z0"Q`&@(O?>U%D\$1G]$.$;_]Z?[(48%1@BQ`W@KN1%(>$0#L+WH
M\$"?Y/_W*NFPN2!&__?PZ09&*$;_]^SI,$0",/_W\N@&1@A+"$DB1GE$`)5[
M1/_WSNDQ1CA&X><#L/"]&1,```43```8$@``]1(``"WI\$_?^#PDW_@\-*WU
M`4V)L'I$W_@T5--8#?4!04BL?40;:,MA3_```RH=I/%T`P7Q$`ZD\5P,'#$&
M1@?*@^@'`+[H#P"LZ`\`GN@#`*3Q:`,H-8SH`P"5Z`<`@^@'`/M(_$]X1/_W
M0_M_1`5&T+$#>,.Q__>.__=*\TMZ1`WU`4'36!PQ&F@+:%I`3_```P'0__>.
MZ2A&#?4!30FPO>CP3__WI[C_]VW_!4:8N:3Q:`A8^`0+$+GH37U$"^#_]Q?[
M`"CUT`-X`"ORT/_WE.@%1@`H[=`H1O_W9.E```$P__=JZ(%&@$;?^'2C`3WZ
M1!7X`2\`*F;1I/%<"%CX!%N%L2A&__?T^@5&`"CVT`-X`"OST/_WNOL`*._0
M*$;_]VSH!4:D\70*1;E:^`2+N/$`#UG0F/@`,``K2]$H1O_W,NF"1DA&__<N
MZ8)$"O($2E!&__<RZ(!&PDO#27M$`)/"2RI&>T1Y1,WX!)#_]PCI3_3@<4!&
M__?<Z`$P-M'_]]+H`V@1*S'0N4JZ2;A8`),R:$-&`&AY1/_WE.@`);9*J4MZ
M1`WU`4'36!PQ&F@+:%I`3_```W_T;*\H1@WU`4T)L+WH\(]`1E%&__?:Z`CQ
M`@B-YT!&__=9^P`HI=!`1O_W"N@%1I_G14:GYT!&!*G_]ZSH@49(L9U+H$GX
M6#)H0T9Y1`!H__=>Z,?GI/6(=2MI`_1P0[/U@$_MT53X^+S_]\SH@T7GT2MI
MP_,(`[/UX'_AT5!&_O?`[P5&D$AX1/_W5OH!1@`H?]$W:#A&__>JZ`,H@D8>
MV8I)!#AY1#A$_O>&[[BYNO$$#P30ND0:^`4\+RL/T79H;K$P1O_WDN@#*`C9
M@$D$.'E$,$3^]W#O`"@(OS=&__=5_H)&`"A`\)R``48X1O[WKN\&1@`H`/"4
M@$_P`@E/\/\S;_`1`LWX`)`G'_[W2.\&(CE&,$;_]Q+H%/@$/``K/]$4^`,\
M0RL[T13X`CQ!*S?1%/@!/$,K,]$C>$@K,-%C>$4K+=%/\/\S;_`Y`C!&S?@`
MD/[W).\I(CE&,$;^]^[O0D9;2UQ)>T3-Z0!S6TMY1'M$*$;_]RCH0$;_]P3H
M5T@I1GA$__?;^BA&__<F_BGG,&C_]R3\!T8`*'_T>J]WYP`C`"(`DS!&`"/^
M]_CN`/#P_8%&3_0`0CE&,$;^][[O`AXHW#!&I/%$!O[WJN^D\3`'248P1@#P
M6_ZY1M_X!+'[1#A&6486^`$K"O$!"O[WZN^Z\10/!_$"!_+1`",$^`@\.$LY
M27M$S>D`DSA+0D9[1'E$K><Y1DA&`/#8_<GG-$DT2'E$>$3_]XGZ_O>^[C)+
M,DE[1,WI``,Q2T)&*$9[1'E$_O?`[R],+TXP3WQ$?D1_1$_TX'$H1O[WC.\!
M,(K1_O>"[P-H$2N%T?[WGNX)\0$)`)`C1D)&,48H1LWI`9?^]Z#OY><`OW)?
M`0`@`0``I&`!`'X1```:7P$`"%\!``D2``#<$0``?!$``&D1``"6$`````$`
M`$<1``#B70$`%A$``(`0```/$0``Z!````@1``!-$```T`X``*8.```P#P``
M:!```*D/```P#@``TPX``%D.```Z$```B`\````.``#R#0``B`\``!P0``!P
MM55+54I[1)Q8(&C^]TSO!48@:/[W2.^5^&0P@/AE,$](>$3_]_[X(+$#>#$K
M`=%#>`NQ__=<_"!H_O<V[TE)`R,!(GE$_O>*[@5&H+$@:/[W*N_K:$1*&6AZ
M1/[WBN[K:!MHFVA;`@;5(&C^]QSOZV@9:/[W+NX@:/[W%N\[20,C`2)Y1/[W
M:NX%1NBQ.$AX1/_WQ_@&1D"Q(&C^]P3O,D;K:!EH_O=F[@[@__>B^@9&(&B6
ML_[W^.[K:#)&&6C^]UCN,$;^]];N(&C^]^SN!48@:/[WZ.XF20$B>43^][+M
M)4H!1GI$*$;^]T3N(&C^]]KN`".`^&4P($@@3'A$__>0^'Q$H&"`N6!H__<2
M_:!@6+D;2'A$_O>L[?[WQ.X92WM$6FCK:!)HN^<73$_TX'%\1*!H_O>6[A$H
M`T8)T$(<`2H&V1)(U.D!$@EH>$3^]Y#M<+T`O[):`0`8`0``+PT``),.``!_
M#@``6@X``(\,```$#@``#PX``!@,``!(6P$`Y0T``"I;`0`:6P$`S@T``#BU
M!$;_]UO[__=0^P5&__=I_'"Q;+$C>%NQ!DDH1GE$_O?&[85"!-$@1KWH.$#_
M]X>X.+U:#```+>GP3_U*_DMZ1-.PTU@!JA1&&VA1DT_P``,`\5P%`/$<`U/X
M!!L)NIU"1/@$&_C10"011@UJ2VL$,FM`C6@):&M`2T!/ZO-S`3S38_'1Z4_0
MZ0#F`9D":3E$T/@(P!%$PFC$:(SJ`@(R0&)``>O^81%$`IJ,ZK8%.D0%Z@X%
M(D2%Z@P%3^J^!!5$`YJ$ZK8*"NH!"CI$BNJV"F)$DD0$F@7K\66$ZK$)">H%
M"3I$`NNV`HGJ!`D*Z_5JD41/ZK4%!9J%ZK$(".H*"#I$(D2(ZK$(D$0&F@GK
M^FF%ZKH$!.H)!#I$`NNQ`FQ`".OY:!1$3^JY"0>:B>JZ`0'J"`$Z1"I$@>JZ
M`1%$")H$Z_ADB>JX!25`.D0"Z[H"A>H)!0'K]&$51$_JM`0)FH3JN`H*Z@$*
M.D1*1(KJN`J21`J:!>OQ983JL0D)Z@4).D0"Z[@"B>H$"0KK]6J11$_JM04+
MFH7JL0@(Z@H(.D0B1(CJL0B01`R:">OZ:87JN@0$Z@D$.D0"Z[$";$`(Z_EH
M%$1/ZKD)#9J)ZKH!`>H(`3I$*D2!ZKH!$40.F@3K^&2)ZK@%)4`Z1`+KN@*%
MZ@D%`>OT815$3^JT!`^:A.JX"POJ`0LZ1$I$B^JX"Y-$$)H%Z_%EA.JQ"0GJ
M!0DZ1`+KN`*)Z@0)"^OU:Y%$3^JU!1&:A>JQ"@KJ"PHZ1")$BNJQ"I)$$IH)
MZ_MIA>J[!#I$"NOY:@+KL0($Z@D$$YE/ZKD)B>J["&Q`%$0(Z@H(%)HY1`3K
M^F0I1(CJNPB)ZKH%B$0E0&E).D05GPCK]&@"Z[L"3^JT!(7J"0451`]$A.JZ
M`H+J"`)/1!=$%IH%Z_AE`NL!"83JN`)J0`GKN@F11!>:!^OU9T_JM04"ZP$*
MA>JX`GI`HD221!B:">OW:508A>JW`H+J"0($Z[@$%$09F@KK^6I/ZKD)`NL!
M"(GJMP*"Z@H"J$201!J:!.OZ9%48!>NW!8GJN@(;GPCK]&AB0$_JM`051`]$
MA.JZ`H+J"`)/1!=$')H%Z_AE`NL!"83JN`)J0`GKN@F11!V:!^OU9T_JM04"
MZP$*A>JX`GI`HD221!Z:">OW:508A>JW`H+J"0($Z[@$%$0?F@KK^6I/ZKD)
M`NL!"(GJMP*"Z@H"J$201"":!.OZ9%48!>NW!8GJN@(AGPCK]&AB0$_JM`05
M1`]$A.JZ`H+J"`)/1!=$(IH%Z_AE`NL!"83JN`)J0`GKN@F11".:!^OU9T_J
MM04"ZP$*A>JX`GI`HD221"2:">OW:508A>JW`H+J"0($Z[@$%$0EF@KK^6I/
MZKD)`NL!"(GJMP*"Z@H"J$201"::!.OZ9%48".``OYEY@EJAZ]ENY%@!`"`!
M```%Z[<%B>JZ`B>?".OT:&)`3^JT!!5$#T2$ZKH"@NH(`D]$%T0HF@7K^&4"
MZP$)A.JX`@?K]6=J0$_JM04)Z[H)1>JX"I%$"NH'"@7JN`(IF4KJ`@KK2@GK
M]VD11"%$1>JW!(I$!.H)!`7JMP$,0RJ9"NOY:A%$3^JY"0'KN`%)ZK<(#$0(
MZ@H(">JW`4CJ`0@KF03K^F011"E$2>JZ!8A$)4`)ZKH!#4,LF0CK]&@11$_J
MM`0!Z[<!1.JZ!PU$!^H(!P3JN@$/0RV9!>OX91%$241$ZK@)#T0)Z@4)!.JX
M`4GJ`0DNF0?K]6<11$_JM04!Z[H!1>JX"HE$"NH'"@7JN`%*Z@$*+YD)Z_=I
M$40A1$7JMP2*1`3J"00%ZK<!#$,PF0KK^6H11$_JN0D!Z[@!2>JW"`Q$".H*
M"`GJMP%(Z@$(,9D$Z_ID$40I1$GJN@6(1"5`">JZ`0U#,ID(Z_1H$41/ZK0$
M`>NW`43JN@<-1`?J"`<$ZKH!#T,SF07K^&411$E$1.JX"0]$">H%"03JN`%)
MZ@$)-)D'Z_5G$41/ZK4%`>NZ`47JN`J)1`KJ!PH%ZK@!2NH!"C69">OW:1%$
M(41%ZK<$BD0$Z@D$!>JW`0Q#-ID*Z_EJ$41/ZKD)`>NX`4GJMP@,1`CJ"@@)
MZK<!2.H!"#>9!.OZ9!%$*42(1$GJN@$)ZKH%(4`I0SB=".OT:!5$3^JT!`7K
MMP4I1$3JN@4$ZKH'!>H(!3U#.9\!Z_AA%T1/1$3JN`D]1`GJ`0D$ZK@'2>H'
M"3J?!>OQ91=$3^JQ`0?KN@=!ZK@*N40*Z@4*`>JX!TKJ!PH[GPGK]6D71"=$
M0>JU!`3J"0171`'JM0I$Z@H*/)P'Z_EG%$0$Z[@$`O%M4@KK!`@"]>`B/9P"
M\OI"3^JY"11$#$2)ZK4!>4`,1#Z9".OW:!%$`>NU`8GJMP6%Z@@%*40_G03K
M^&051$_JN`BI1(CJMP5E0*E$0)T!Z_1A%40%Z[<%B.JT!T]`/41!GT_JL0H)
MZ_%I%T2*ZK0!@>H)`4=$#T1"F07K^6411`'KM`&*ZKD$;$`A1$.<!^OU9T_J
MM04$ZP((A>JY!'Q`T$2@1$2<`>OW811$!.NY!(7JMPF)Z@$)".OQ:$Q$3^JQ
M"469!.OX9`'K`@J)ZK<!@>H(`:I$BD1&F8GJN`411&5``>NW`2E$1YU/ZK0+
M"NOT:A5$B^JX!(3J"@1-1"5$2)P!Z_IA%$2+ZKH'3T`$Z[@$/$1)GT_JL0@%
MZ_%E%T2(ZKH!:4!?1`]$2ID$Z_5DB.JU"1%$B>H$"0'KN@$'Z_1G241/ZK0)
M2YP!Z_=A%$2@1(GJM01\0*!$3)Q/ZK$*%$0$Z[4$B>JW!4U`+$0!X-R\&X]-
MG0CK\6@51$Z9342*ZK<)B>H("4U$`>L""03K^&0)Z[<)BNJX!P&K9T"Y1-/X
M.''3^#PQ!>OT94_JM`071(3JN`$31`GK]6F$ZK4":4!71'-$@NH)`@]$`^NX
M`P?K^6<31`/K]V,#8`SKN0.#8,-H"TH#Z[4%`VD^1!Q$"4MZ1$9@Q6`$8=-8
M&FA1FUI`3_```P'0_O<ZZE.PO>CPCP"_8E`!`"`!```(M6`@_O<RZ0I*"TD"
M8`+QB#)"8`+Q*4*B]982HO:+8H)@HO&(,L)@`"+`Z002@F'"90B]`2-%9_#A
MTL,MZ?!!%D8%1D-IT@";&"B_@FE#822_`3*"88-I!?$<!P/K5G.#8<!M\+'`
M\4`$M$(X1*B_-$:(0@/2`QF90@#2_]Z(0@'K!`@!V4!%^-,B1O[WV.GK;2-$
M0"OK91?1*$;_]U;[048V&P7Q7`@_+A#<N4("V;L9F4+BT[E"`M*+&9]"W=,R
M1CA&_O>\Z>YEO>CP@;E"`=E!1=+3CT(!\4`#`=F?0LS3#$8Z1E3X!!N<0D+X
M!!OYT2A&__<J^T`^(4;4YRWI\$$!\1P'2VF.:0Q&@"&3^H/XP_/%`UH<."H%
M1C:Z^50'ZP(`0]T`(<+Q0`+^]XSH($;_]PO[."(`(3A&_O>$Z"!&Q.D5:/_W
M`?OC>"!&*W!CB&MP(V@;"JMP(VCK<.-Y*W'CB&MQ8V@;"JMQ8VCK<>-Z*W)C
MB6MRHV@;"JMRHVCK<N-[*W/CB6MSXV@;"JMSXVCK<^-\*W1CBFMT(VD;"JMT
M(VGK=+WH\$'^]R&Y`"'"\3@"PN<`OP&UO>@!0'!'.P```#X````+````/@``
M`!`````^````)0```#X````S````/@````,````^````!@```#X````4````
M/@````X````^````#0```#X````D````/@```!(````^````)P```#X````"
M````/@```!@````^````"0```#X````*````/@``````````````+BX`)7,O
M)7,`1'EN84QO861E<CHZ8F]O=%]$>6YA3&]A9&5R`$EN=&5R;F%L<SHZ4$%2
M.CI"3T]4`"]P<F]C+R5I+R5S`&5X90!005)?5$5-4`!005)?4%)/1TY!344`
M.@`O`%!%4DPU3$E"`%!%4DQ,24(`4$523#5/4%0`4$523$E/`%!!4E])3DE4
M24%,25I%1`!005)?4U!!5TY%1`!005)?0TQ%04X`4$%27T1%0E5'`%!!4E]#
M04-(10!005)?1TQ/0D%,7T1%0E5'`%!!4E]'3$]"04Q?5$U01$E2`%!!4E]4
M35!$25(`4$%27T=,3T)!3%]414U0`%!!4E]'3$]"04Q?0TQ%04X`4$%27T-,
M14%./0`Q`$Q$7TQ)0E)!4EE?4$%42`!365-414T`)3`R>``E<R5S)7,E<P!P
M87(M`"5S.B!C<F5A=&EO;B!O9B!P<FEV871E('-U8F1I<F5C=&]R>2`E<R!F
M86EL960@*&5R<FYO/25I*0H`)7,Z('!R:79A=&4@<W5B9&ER96-T;W)Y("5S
M(&ES('5N<V%F92`H<&QE87-E(')E;6]V92!I="!A;F0@<F5T<GD@>6]U<B!O
M<&5R871I;VXI"@!P87)L`"YP87(`)7,E<V-A8VAE+25S)7,`)7,E<W1E;7`M
M)74E<P`E<R5S=&5M<"TE=2TE=25S`!@`<&5R;``P`%!!4CHZ4&%C:V5R.CI6
M15)324].`#$N,#4T`%5N86)L92!T;R!C<F5A=&4@8V%C:&4@9&ER96-T;W)Y
M`"5S.B!C<F5A=&EO;B!O9B!P<FEV871E(&-A8VAE('-U8F1I<F5C=&]R>2`E
M<R!F86EL960@*&5R<FYO/25I*0H`+64`+2T`55-%4@!54T523D%-10!414U0
M1$E2`%1-4``O=&UP`&5V86P@)V5X96,@+W5S<B]B:6XO<&5R;"`@+5,@)#`@
M)'LQ*R(D0")])PII9B`P.R`C(&YO="!R=6YN:6YG('5N9&5R('-O;64@<VAE
M;&P*<&%C:V%G92!?7W!A<E]P;#L*;7D@*"1005)?34%'24,L("1P87)?=&5M
M<"P@)'!R;V=N86UE+"!`=&UP9FEL92P@)4UO9'5L94-A8VAE*3L*14Y$('L@
M:68@*"1%3E9[4$%27T-,14%.?2D@>PIR97%U:7)E($9I;&4Z.E1E;7`["G)E
M<75I<F4@1FEL93HZ0F%S96YA;64["G)E<75I<F4@1FEL93HZ4W!E8SL*;7D@
M)'1O<&1I<B`]($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1P87)?=&5M<"D[
M"F]U=',H<7%;4F5M;W9I;F<@9FEL97,@:6X@(B1P87)?=&5M<")=*3L*1FEL
M93HZ1FEN9#HZ9FEN9&1E<'1H*'-U8B![("@@+60@*2`_(')M9&ER(#H@=6YL
M:6YK('TL("1P87)?=&5M<"D["G)M9&ER("1P87)?=&5M<#L*:68@*"UD("1P
M87)?=&5M<"`F)B`D7D\@;F4@)TU35VEN,S(G*2!["FUY("1T;7`@/2!N97<@
M1FEL93HZ5&5M<"@*5$5-4$Q!5$4@/3X@)W1M<%A86%A8)RP*1$E2(#T^($9I
M;&4Z.D)A<V5N86UE.CID:7)N86UE*"1T;W!D:7(I+`I3549&25@@/3X@)RYC
M;60G+`I53DQ)3DL@/3X@,"P**3L*;7D@)&9I;&5N86UE(#T@)'1M<"T^9FEL
M96YA;64["G!R:6YT("1T;7`@/#PB+BXN(CL*>#TQ.R!W:&EL92!;(%PD>"`M
M;'0@,3`@73L@9&\*<FT@+7)F("<D<&%R7W1E;7`G"FEF(%L@7"$@+60@)R1P
M87)?=&5M<"<@73L@=&AE;@IB<F5A:PIF:0IS;&5E<"`Q"G@]8&5X<'(@7"1X
M("L@,6`*9&]N90IR;2`G)&9I;&5N86UE)PHN+BX*8VQO<V4@)'1M<#L*8VAM
M;V0@,#<P,"P@)&9I;&5N86UE.PIM>2`D8VUD(#T@(B1F:6QE;F%M92`^+V1E
M=B]N=6QL(#(^)C$@)B(["G-Y<W1E;2@D8VUD*3L*;W5T<RAQ<5M3<&%W;F5D
M(&)A8VMG<F]U;F0@<')O8V5S<R!T;R!P97)F;W)M(&-L96%N=7`Z("1F:6QE
M;F%M95TI.PI]"GT@?0I"14=)3B!["B1005)?34%'24,@/2`B7&Y005(N<&U<
M;B(["DEN=&5R;F%L<SHZ4$%2.CI"3T]4*"D@:68@9&5F:6YE9"`F26YT97)N
M86QS.CI005(Z.D)/3U0["F5V86P@>PI?<&%R7VEN:71?96YV*"D["FUY("1Q
M=6EE="`]("$D14Y6>U!!4E]$14)51WT["FUY("5S>7,@/2`H"G!A=&A?<V5P
M("`@(#T^("@D7D\@/7X@+UY-4U=I;B\@/R`G.R<@.B`G.B<I+`I?97AE("`@
M("`@("`]/B`H)%Y/(#U^("]>*#\Z35-7:6Y\3U,R?&-Y9W=I;BDO(#\@)RYE
M>&4G(#H@)R<I+`I?9&5L:6T@("`@("`]/B`H)%Y/(#U^("]>35-7:6Y\3U,R
M+R`_("=<7"<@.B`G+R<I+`HI.PI?<V5T7W!R;V=N86UE*"D["F]U=',H<7%;
M7"1P<F]G;F%M92`]("(D<')O9VYA;64B72D["E]S971?<&%R7W1E;7`H*3L*
M;W5T<RAQ<5M<)$5.5GM005)?5$5-4'T@/2`B)$5.5GM005)?5$5-4'TB72D[
M"FUY("@D<W1A<G1?<&]S+"`D9&%T85]P;W,I.PI-04=)0SH@>PIL;V-A;"`D
M4TE'>U]?5T%23E]??2`]('-U8B![?3L*=6YL97-S("AO<&5N(%]&2"P@)SPZ
M<F%W)RP@)'!R;V=N86UE*2!["F]U=',H<7%;0V%N)W0@<F5A9"!F<F]M(&9I
M;&4@(B1P<F]G;F%M92)=*3L@(",@9&]N)W0@=7-E("0A(&AE<F4@87,@:70@
M<F5Q=6ER97,@17)R;F\N<&T*;&%S="!-04=)0SL*?0IM>2`D8VAU;FM?<VEZ
M92`](#8T("H@,3`R-#L*;7D@)&)U9CL*;7D@)'-I>F4@/2`M<R!?1D@["FUY
M("1M86=I8U]P;W,@/2`D<VEZ92`M("1S:7IE("4@)&-H=6YK7W-I>F4[(",@
M3D]413H@)&UA9VEC7W!O<R!I<R!A(&UU;'1I<&QE(&]F("1C:'5N:U]S:7IE
M"G=H:6QE("@D;6%G:6-?<&]S(#X](#`I('L*<V5E:R!?1D@L("1M86=I8U]P
M;W,L(#`["G)E860@7T9(+"`D8G5F+"`D8VAU;FM?<VEZ92`K(&QE;F=T:"@D
M4$%27TU!1TE#*3L*:68@*"AM>2`D:2`](')I;F1E>"@D8G5F+"`D4$%27TU!
M1TE#*2D@/CT@,"D@>PHD;6%G:6-?<&]S("L]("1I.PIL87-T.PI]"B1M86=I
M8U]P;W,@+3T@)&-H=6YK7W-I>F4["GT*:68@*"1M86=I8U]P;W,@/"`P*2![
M"F]U=',H<7%;0V%N)W0@9FEN9"!M86=I8R!S=')I;F<@(B1005)?34%'24,B
M(&EN(&9I;&4@(B1P<F]G;F%M92)=*3L*;&%S="!-04=)0SL*?0IS965K(%]&
M2"P@)&UA9VEC7W!O<R`M(#0L(#`["G)E860@7T9(+"`D8G5F+"`T.PIS965K
M(%]&2"P@)&UA9VEC7W!O<R`M(#0@+2!U;G!A8VLH(DXB+"`D8G5F*2P@,#L*
M)&1A=&%?<&]S(#T@=&5L;"!?1D@["FUY("5R97%U:7)E7VQI<W0["G)E860@
M7T9(+"`D8G5F+"`T.R`@("`@("`@("`@("`@("`@("`@("`@("`@(",@<F5A
M9"!T:&4@9FER<W0@(D9)3$4B"G=H:6QE("@D8G5F(&5Q(")&24Q%(BD@>PIR
M96%D(%]&2"P@)&)U9BP@-#L*<F5A9"!?1D@L("1B=68L('5N<&%C:R@B3B(L
M("1B=68I.PIM>2`D9G5L;&YA;64@/2`D8G5F.PIO=71S*'%Q6U5N<&%C:VEN
M9R!&24Q%("(D9G5L;&YA;64B+BXN72D["FUY("1C<F,@/2`H("1F=6QL;F%M
M92`]?B!S?%XH6V$M9EQD77LX?2DO?'P@*2`_("0Q(#H@=6YD968["FUY("@D
M8F%S96YA;64L("1E>'0I(#T@*"1B=68@/7X@;7PH/SHN*B\I/R@N*BDH7"XN
M*BE\*3L*<F5A9"!?1D@L("1B=68L(#0["G)E860@7T9(+"`D8G5F+"!U;G!A
M8VLH(DXB+"`D8G5F*3L*:68@*&1E9FEN960H)&5X="D@86YD("1E>'0@(7X@
M+UPN*#\Z<&U\<&Q\:7A\86PI)"]I*2!["FUY("1F:6QE;F%M92`](%]S879E
M7V%S*"(D8W)C)&5X="(L("1B=68L(#`W-34I.PHD4$%2.CI(96%V>3HZ1G5L
M;$-A8VAE>R1F=6QL;F%M97T@/2`D9FEL96YA;64["B1005(Z.DAE879Y.CI&
M=6QL0V%C:&5[)&9I;&5N86UE?2`]("1F=6QL;F%M93L*?0IE;'-I9B`H("1F
M=6QL;F%M92`]?B!M?%XO/W-H;&EB+WP@86YD(&1E9FEN960@)$5.5GM005)?
M5$5-4'T@*2!["FUY("1F:6QE;F%M92`](%]S879E7V%S*"(D8F%S96YA;64D
M97AT(BP@)&)U9BP@,#<U-2D["F]U=',H(E-(3$E".B`D9FEL96YA;65<;B(I
M.PI]"F5L<V4@>PHD36]D=6QE0V%C:&5[)&9U;&QN86UE?2`]('L*8G5F(#T^
M("1B=68L"F-R8R`]/B`D8W)C+`IN86UE(#T^("1F=6QL;F%M92P*?3L*)')E
M<75I<F5?;&ES='LD9G5L;&YA;65]*RL["GT*<F5A9"!?1D@L("1B=68L(#0[
M"GT*;&]C86P@0$E.0R`]("AS=6(@>PIM>2`H)'-E;&8L("1M;V1U;&4I(#T@
M0%\["G)E='5R;B!I9B!R968@)&UO9'5L92!O<B`A)&UO9'5L93L*;7D@)&EN
M9F\@/2`D36]D=6QE0V%C:&5[)&UO9'5L97T["G)E='5R;B!U;FQE<W,@)&EN
M9F\["F1E;&5T92`D<F5Q=6ER95]L:7-T>R1M;V1U;&5].PHD24Y#>R1M;V1U
M;&5](#T@(B]L;V%D97(O)&EN9F\O)&UO9'5L92(["FEF("@D14Y6>U!!4E]#
M3$5!3GT@86YD(&1E9FEN960H)DE/.CI&:6QE.CIN97<I*2!["FUY("1F:"`]
M($E/.CI&:6QE+3YN97=?=&UP9FEL92!O<B!D:64@(D-A;B=T(&-R96%T92!T
M96UP(&9I;&4Z("0A(CL*)&9H+3YB:6YM;V1E*"D["B1F:"T^<')I;G0H)&EN
M9F\M/GMB=69]*3L*)&9H+3YS965K*#`L(#`I.PIR971U<FX@)&9H.PI]"F5L
M<V4@>PIM>2`D9FEL96YA;64@/2!?<V%V95]A<R@B)&EN9F\M/GMC<F-]+G!M
M(BP@)&EN9F\M/GMB=69]*3L*)&EN9F\M/GMF:6QE?2`]("1F:6QE;F%M93L*
M;W!E;B!M>2`D9F@L("<\.G)A=R<L("1F:6QE;F%M92!O<B!D:64@<7%;0V%N
M)W0@<F5A9"`B)&9I;&5N86UE(CH@)"%=.PIR971U<FX@)&9H.PI]"F1I92`B
M0F]O='-T<F%P<&EN9R!F86EL960Z(&-A;B=T(&9I;F0@;6]D=6QE("1M;V1U
M;&4A(CL*?2P@0$E.0RD["G)E<75I<F4@6%-,;V%D97(["G)E<75I<F4@4$%2
M.CI(96%V>3L*<F5Q=6ER92!#87)P.CI(96%V>3L*<F5Q=6ER92!%>'!O<G1E
M<CHZ2&5A=GD["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*<F5Q
M=6ER92!)3SHZ1FEL93L*=VAI;&4@*&UY("1F:6QE;F%M92`]("AS;W)T(&ME
M>7,@)7)E<75I<F5?;&ES="E;,%TI('L*=6YL97-S("@D24Y#>R1F:6QE;F%M
M97T@;W(@)&9I;&5N86UE(#U^("]"4T1004XO*2!["FEF("@D9FEL96YA;64@
M/7X@+UPN<&UC/R0O:2D@>PIR97%U:7)E("1F:6QE;F%M93L*?0IE;'-E('L*
M9&\@)&9I;&5N86UE('5N;&5S<R`D9FEL96YA;64@/7X@+W-I=&5C=7-T;VUI
M>F5<+G!L)"\["GT*?0ID96QE=&4@)')E<75I<F5?;&ES='LD9FEL96YA;65]
M.PI]"G5N;&5S<R`H)&)U9B!E<2`B4$M<,#`S7#`P-"(I('L*;W5T<RAQ<5M.
M;R!Z:7`@9F]U;F0@869T97(@1DE,12!S96-T:6]N(&EN(&9I;&4@(B1P<F]G
M;F%M92)=*3L*;&%S="!-04=)0R`["GT*)'-T87)T7W!O<R`]("AT96QL(%]&
M2"D@+2`T.R`@("`@("`@("`@("`@("`C('-T87)T(&]F('II<`I]"FUY($!P
M87)?87)G<SL*;7D@*"1O=70L("1B=6YD;&4L("1L;V=F:"P@)&-A8VAE7VYA
M;64I.PID96QE=&4@)$5.5GM005)?05!07U)%55-%?3L@(R!S86YI=&EZ92`H
M4D554T4@;6%Y(&)E(&$@<V5C=7)I='D@<')O8FQE;2D*)'%U:65T(#T@,"!U
M;FQE<W,@)$5.5GM005)?1$5"54=].PII9B`H(21S=&%R=%]P;W,@;W(@*"1!
M4D=66S!=(&5Q("<M+7!A<BUO<'1I;VYS)R`F)B!S:&EF="DI('L*;7D@)61I
M<W1?8VUD(#T@<7<H"G`@("!B;&EB7W1O7W!A<@II("`@:6YS=&%L;%]P87(*
M=2`@('5N:6YS=&%L;%]P87(*<R`@('-I9VY?<&%R"G8@("!V97)I9GE?<&%R
M"BD["FEF("A`05)'5B!A;F0@)$%21U9;,%T@97$@)RTM<F5U<V4G*2!["G-H
M:69T($!!4D=6.PHD14Y6>U!!4E]!4%!?4D554T5](#T@<VAI9G0@0$%21U8[
M"GT*96QS92![(",@;F]R;6%L('!A<FP@8F5H879I;W5R"FUY($!A9&1?=&]?
M:6YC.PIW:&EL92`H0$%21U8I('L*)$%21U9;,%T@/7X@+UXM*%M!24U/0DQB
M<7!I=7-4=ETI*"XJ*2\@;W(@;&%S=#L*:68@*"0Q(&5Q("=))RD@>PIP=7-H
M($!A9&1?=&]?:6YC+"`D,CL*?0IE;'-I9B`H)#$@97$@)TTG*2!["F5V86P@
M(G5S92`D,B(["GT*96QS:68@*"0Q(&5Q("=!)RD@>PIU;G-H:69T($!P87)?
M87)G<RP@)#(["GT*96QS:68@*"0Q(&5Q("=/)RD@>PHD;W5T(#T@)#(["GT*
M96QS:68@*"0Q(&5Q("=B)RD@>PHD8G5N9&QE(#T@)W-I=&4G.PI]"F5L<VEF
M("@D,2!E<2`G0B<I('L*)&)U;F1L92`]("=A;&PG.PI]"F5L<VEF("@D,2!E
M<2`G<2<I('L*)'%U:65T(#T@,3L*?0IE;'-I9B`H)#$@97$@)TPG*2!["F]P
M96X@)&QO9V9H+"`B/CXB+"`D,B!O<B!D:64@<7%;0V%N)W0@;W!E;B!L;V<@
M9FEL92`B)#(B.B`D(5T["GT*96QS:68@*"0Q(&5Q("=4)RD@>PHD8V%C:&5?
M;F%M92`]("0R.PI]"G-H:69T*$!!4D=6*3L*:68@*&UY("1C;60@/2`D9&ES
M=%]C;61[)#%]*2!["F1E;&5T92`D14Y6>R=005)?5$5-4"=].PII;FET7VEN
M8R@I.PIR97%U:7)E(%!!4CHZ1&ES=#L*)GLB4$%2.CI$:7-T.CHD8VUD(GTH
M*2!U;FQE<W,@0$%21U8["B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"1?*2!F;W(@
M0$%21U8["F5X:70["GT*?0IU;G-H:69T($!)3D,L($!A9&1?=&]?:6YC.PI]
M"GT*:68@*"1O=70I('L*>PIR97%U:7)E($E/.CI&:6QE.PIR97%U:7)E($%R
M8VAI=F4Z.EII<#L*<F5Q=6ER92!$:6=E<W0Z.E-(03L*?0IM>2`D<&%R(#T@
M<VAI9G0H0$%21U8I.PIM>2`D>FEP.PII9B`H9&5F:6YE9"`D<&%R*2!["F]P
M96X@;7D@)&9H+"`G/#IR87<G+"`D<&%R(&]R(&1I92!Q<5M#86XG="!F:6YD
M('!A<B!F:6QE("(D<&%R(CH@)"%=.PIB;&5S<R@D9F@L("=)3SHZ1FEL92<I
M.PHD>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["B@@)'II<"T^<F5A9$9R;VU&
M:6QE2&%N9&QE*"1F:"P@)'!A<BD@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I
M("D*;W(@9&EE('%Q6T5R<F]R(')E861I;F<@>FEP(&%R8VAI=F4@(B1P87(B
M73L*?0IM>2`E96YV(#T@9&\@>PII9B`H)'II<"!A;F0@;7D@)&UE=&$@/2`D
M>FEP+3YC;VYT96YT<R@G345402YY;6PG*2D@>PHD;65T82`]?B!S+RXJ7G!A
M<CHD+R]M<SL*)&UE=&$@/7X@<R]>7%,N*B\O;7,["B1M971A(#U^("]>("`H
M6UXZ72LI.B`H+BLI)"]M9SL*?0I].PII9B`H9&5F:6YE9"`D<&%R*2!["F]P
M96X@;7D@)'!H+"`G/#IR87<G+"`D<&%R(&]R(&1I92!Q<5M#86XG="!R96%D
M('!A<B!F:6QE("(D<&%R(CH@)"%=.PIM>2`D8G5F.PIR96%D("1P:"P@)&)U
M9BP@-#L*9&EE('%Q6R(D<&%R(B!I<R!N;W0@82!P87(@9FEL95T@=6YL97-S
M("1B=68@97$@(E!+7#`P,UPP,#0B.PIC;&]S92`D<&@["GT*0W)E871E4&%T
M:"@D;W5T*2`["FUY("1F:"`]($E/.CI&:6QE+3YN97<H"B1O=70L"DE/.CI&
M:6QE.CI/7T-214%4*"D@?"!)3SHZ1FEL93HZ3U]74D].3%DH*2!\($E/.CI&
M:6QE.CI/7U1254Y#*"DL"C`W-S<L"BD@;W(@9&EE('%Q6T-A;B=T(&-R96%T
M92!F:6QE("(D;W5T(CH@)"%=.PHD9F@M/F)I;FUO9&4H*3L*<V5E:R!?1D@L
M(#`L(#`["FUY("1L;V%D97(["FEF("AD969I;F5D("1D871A7W!O<RD@>PIR
M96%D(%]&2"P@)&QO861E<BP@)&1A=&%?<&]S.PI](&5L<V4@>PIL;V-A;"`D
M+R`]('5N9&5F.PHD;&]A9&5R(#T@/%]&2#X["GT*:68@*"$D14Y6>U!!4E]6
M15)"051)37T@86YD("1L;V%D97(@/7X@+UXH/SHC(7Q<0')E;2DO*2!["G)E
M<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PI005(Z.D9I;'1E<CHZ4&]D
M4W1R:7`M/F%P<&QY*%PD;&]A9&5R+"`D,"D["GT*9F]R96%C:"!M>2`D:V5Y
M("AS;W)T(&ME>7,@)65N=BD@>PIM>2`D=F%L(#T@)&5N=GLD:V5Y?2!O<B!N
M97AT.PHD=F%L(#T@979A;"`D=F%L(&EF("1V86P@/7X@+UY;)R)=+SL*;7D@
M)&UA9VEC(#T@(E]?14Y67U!!4E\B("X@=6,H)&ME>2D@+B`B7U\B.PIM>2`D
M<V5T(#T@(E!!4E\B("X@=6,H)&ME>2D@+B`B/21V86PB.PHD;&]A9&5R(#U^
M('-[)&UA9VEC*"`K*7U["B1M86=I8R`N("1S970@+B`H)R`G('@@*&QE;F=T
M:"@D,2D@+2!L96YG=&@H)'-E="DI*0I]96<["GT*)&9H+3YP<FEN="@D;&]A
M9&5R*3L*:68@*"1B=6YD;&4I('L*<F5Q=6ER92!005(Z.DAE879Y.PI005(Z
M.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["FEN:71?:6YC*"D["G)E<75I
M<F5?;6]D=6QE<R@I.PIM>2!`:6YC(#T@9W)E<"![("$O0E-$4$%.+R!]"F=R
M97`@>PHH)&)U;F1L92!N92`G<VET92<I(&]R"B@D7R!N92`D0V]N9FEG.CI#
M;VYF:6=[87)C:&QI8F5X<'T@86YD"B1?(&YE("1#;VYF:6<Z.D-O;F9I9WMP
M<FEV;&EB97AP?2D["GT@0$E.0SL*<WPO*WPO?&<L('-\+R1\?"!F;W)E86-H
M($!I;F,["FUY("5F:6QE<SL*)&9I;&5S>R1??2LK(&9O<B!`1'EN84QO861E
M<CHZ9&Q?<VAA<F5D7V]B:F5C=',L('9A;'5E<R`E24Y#.PIM>2`D;&EB7V5X
M="`]("1#;VYF:6<Z.D-O;F9I9WML:6)?97AT?3L@("`@("`@("`C(%A86"!L
M:6)?97AT('9S(&1L97AT(#\*;7D@)7=R:71T96X["F9O<F5A8V@@;7D@)&ME
M>2`H<V]R="!K97ES("5F:6QE<RD@>PIM>2`H)&9I;&4L("1N86UE*3L*:68@
M*&1E9FEN960H;7D@)&9C(#T@)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD:V5Y
M?2DI('L**"1F:6QE+"`D;F%M92D@/2`H)&ME>2P@)&9C*3L*?0IE;'-E('L*
M9F]R96%C:"!M>2`D9&ER("A`:6YC*2!["FEF("@D:V5Y(#U^(&U\7EQ1)&1I
M<EQ%+R@N*BDD?&DI('L**"1F:6QE+"`D;F%M92D@/2`H)&ME>2P@)#$I.PIL
M87-T.PI]"FEF("@D:V5Y(#U^(&U\7B]L;V%D97(O6UXO72LO*"XJ*21\*2![
M"FEF("AM>2`D<F5F(#T@)$UO9'5L94-A8VAE>R0Q?2D@>PHH)&9I;&4L("1N
M86UE*2`]("@D<F5F+"`D,2D["FQA<W0["GT*:68@*"UF("(D9&ER+R0Q(BD@
M>PHH)&9I;&4L("1N86UE*2`]("@B)&1I<B\D,2(L("0Q*3L*;&%S=#L*?0I]
M"GT*?0IN97AT('5N;&5S<R!D969I;F5D("1N86UE.PIN97AT(&EF("1W<FET
M=&5N>R1N86UE?2LK.PIN97AT(&EF("%R968H)&9I;&4I(&%N9"`D9FEL92`]
M?B`O7"Y<421L:6)?97AT7$4D+VD["F]U=',H<W!R:6YT9BAQ<5M086-K:6YG
M($9)3$4@(B5S(BXN+ETL(')E9B`D9FEL92`_("1F:6QE+3Y[;F%M97T@.B`D
M9FEL92DI.PIM>2`D8V]N=&5N=#L*:68@*')E9B@D9FEL92DI('L*)&-O;G1E
M;G0@/2`D9FEL92T^>V)U9GT["GT*96QS92!["FQO8V%L("0O(#T@=6YD968[
M"F]P96X@;7D@)&9H+"`G/#IR87<G+"`D9FEL92!O<B!D:64@<7%;0V%N)W0@
M<F5A9"`B)&9I;&4B.B`D(5T["B1C;VYT96YT(#T@/"1F:#X["F-L;W-E("1F
M:#L*4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YA<'!L>2A<)&-O;G1E;G0L("(\
M96UB961D960^+R1N86UE(BD*:68@(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@
M)&YA;64@/7X@+UPN*#\Z<&U\:7A\86PI)"]I.PI005(Z.D9I;'1E<CHZ4&%T
M8VA#;VYT96YT+3YN97<M/F%P<&QY*%PD8V]N=&5N="P@)&9I;&4L("1N86UE
M*3L*?0HD9F@M/G!R:6YT*")&24Q%(BP*<&%C:R@G3B<L(&QE;F=T:"@D;F%M
M92D@*R`Y*2P*<W!R:6YT9B@B)3`X>"\E<R(L($%R8VAI=F4Z.EII<#HZ8V]M
M<'5T94-20S,R*"1C;VYT96YT*2P@)&YA;64I+`IP86-K*"=.)RP@;&5N9W1H
M*"1C;VYT96YT*2DL"B1C;VYT96YT*3L*;W5T<RAQ<5M7<FET=&5N(&%S("(D
M;F%M92)=*3L*?0I]"B1Z:7`M/G=R:71E5&]&:6QE2&%N9&QE*"1F:"D@:68@
M)'II<#L*)&-A8VAE7VYA;64@/2!S=6)S='(@)&-A8VAE7VYA;64L(#`L(#0P
M.PII9B`H(21C86-H95]N86UE(&%N9"!M>2`D;71I;64@/2`H<W1A="@D;W5T
M*2E;.5TI('L*;7D@)&-T>"`]($1I9V5S=#HZ4TA!+3YN97<H,2D["F]P96X@
M;7D@)&9H+"`B/#IR87<B+"`D;W5T.PHD8W1X+3YA9&1F:6QE*"1F:"D["F-L
M;W-E("1F:#L*)&-A8VAE7VYA;64@/2`D8W1X+3YH97AD:6=E<W0["GT*)&-A
M8VAE7VYA;64@+CT@(EPP(B!X("@T,2`M(&QE;F=T:"`D8V%C:&5?;F%M92D[
M"B1C86-H95]N86UE("X](")#04-(12(["B1F:"T^<')I;G0H)&-A8VAE7VYA
M;64I.PHD9F@M/G!R:6YT*'!A8VLH)TXG+"`D9F@M/G1E;&P@+2!L96YG=&@H
M)&QO861E<BDI*3L*)&9H+3YP<FEN="@D4$%27TU!1TE#*3L*)&9H+3YC;&]S
M93L*8VAM;V0@,#<U-2P@)&]U=#L*97AI=#L*?0I["FQA<W0@=6YL97-S(&1E
M9FEN960@)'-T87)T7W!O<SL*7V9I>%]P<F]G;F%M92@I.PIR97%U:7)E(%!!
M4CL*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PI["G)E<75I<F4@
M1FEL93HZ1FEN9#L*<F5Q=6ER92!!<F-H:79E.CI::7`["GT*;7D@)&9H(#T@
M24\Z.D9I;&4M/FYE=SL@("`@("`@("`@("`@("`@("`@("`@("`@("`@(",@
M07)C:&EV93HZ6FEP(&]P97)A=&5S(&]N(&%N($E/.CI(86YD;&4*)&9H+3YF
M9&]P96XH9FEL96YO*%]&2"DL("=R)RD@;W(@9&EE('%Q6V9D;W!E;B@I(&9A
M:6QE9#H@)"%=.PI!<F-H:79E.CI::7`Z.G-E=$-H=6YK4VEZ92@M<R!?1D@I
M.PIM>2`D>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["B@@)'II<"T^<F5A9$9R
M;VU&:6QE2&%N9&QE*"1F:"P@)'!R;V=N86UE*2`]/2!!<F-H:79E.CI::7`Z
M.D%:7T]+*"D@*0IO<B!D:64@<7%;17)R;W(@<F5A9&EN9R!Z:7`@87)C:&EV
M92`B)'!R;V=N86UE(ET["D%R8VAI=F4Z.EII<#HZ<V5T0VAU;FM3:7IE*#8T
M("H@,3`R-"D["G!U<V@@0%!!4CHZ3&EB0V%C:&4L("1Z:7`["B1005(Z.DQI
M8D-A8VAE>R1P<F]G;F%M97T@/2`D>FEP.PHD<75I970@/2`A)$5.5GM005)?
M1$5"54=].PII9B`H9&5F:6YE9"`D14Y6>U!!4E]414U0?2D@>R`C('-H;W5L
M9"!B92!S970@870@=&AI<R!P;VEN="$*9F]R96%C:"!M>2`D;65M8F5R("@@
M)'II<"T^;65M8F5R<R`I('L*;F5X="!I9B`D;65M8F5R+3YI<T1I<F5C=&]R
M>3L*;7D@)&UE;6)E<E]N86UE(#T@)&UE;6)E<BT^9FEL94YA;64["FYE>'0@
M=6YL97-S("1M96UB97)?;F%M92`]?B!M>PI>"B\_<VAL:6(O"B@_.B1#;VYF
M:6<Z.D-O;F9I9WMV97)S:6]N?2\I/PHH/SHD0V]N9FEG.CI#;VYF:6=[87)C
M:&YA;65]+RD_"BA;7B]=*RD*)`I]>#L*;7D@)&5X=')A8W1?;F%M92`]("0Q
M.PIM>2`D9&5S=%]N86UE(#T@1FEL93HZ4W!E8RT^8V%T9FEL92@D14Y6>U!!
M4E]414U0?2P@)&5X=')A8W1?;F%M92D["FEF("@M9B`D9&5S=%]N86UE("8F
M("US(%\@/3T@)&UE;6)E<BT^=6YC;VUP<F5S<V5D4VEZ92@I*2!["F]U=',H
M<7%;4VMI<'!I;F<@(B1M96UB97)?;F%M92(@<VEN8V4@:70@86QR96%D>2!E
M>&ES=',@870@(B1D97-T7VYA;64B72D["GT@96QS92!["F]U=',H<7%;17AT
M<F%C=&EN9R`B)&UE;6)E<E]N86UE(B!T;R`B)&1E<W1?;F%M92)=*3L*)&UE
M;6)E<BT^97AT<F%C=%1O1FEL94YA;65D*"1D97-T7VYA;64I.PIC:&UO9"@P
M-34U+"`D9&5S=%]N86UE*2!I9B`D7D\@97$@(FAP=7@B.PI]"GT*?0I]"G5N
M;&5S<R`H)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2D@>PID:64@/#P@(BXB
M('5N;&5S<R!`05)'5CL*57-A9V4Z("0P(%L@+4%L:6(N<&%R(%T@6R`M261I
M<B!=(%L@+4UM;V1U;&4@72!;('-R8RYP87(@72!;('!R;V=R86TN<&P@70HD
M,"!;("U"?"UB(%T@6RU/;W5T9FEL95T@<W)C+G!A<@HN"B1%3E9[4$%27U!2
M3T=.04U%?2`]("1P<F]G;F%M92`]("0P(#T@<VAI9G0H0$%21U8I.PI]"G-U
M8B!#<F5A=&50871H('L*;7D@*"1N86UE*2`]($!?.PIR97%U:7)E($9I;&4Z
M.D)A<V5N86UE.PIM>2`H)&)A<V5N86UE+"`D<&%T:"P@)&5X="D@/2!&:6QE
M.CI"87-E;F%M93HZ9FEL97!A<G-E*"1N86UE+"`H)UPN+BHG*2D["G)E<75I
M<F4@1FEL93HZ4&%T:#L*1FEL93HZ4&%T:#HZ;6MP871H*"1P871H*2!U;FQE
M<W,H+64@)'!A=&@I.R`C(&UK<&%T:"!D:65S('=I=&@@97)R;W(*?0IS=6(@
M<F5Q=6ER95]M;V1U;&5S('L*<F5Q=6ER92!L:6(["G)E<75I<F4@1'EN84QO
M861E<CL*<F5Q=6ER92!I;G1E9V5R.PIR97%U:7)E('-T<FEC=#L*<F5Q=6ER
M92!W87)N:6YG<SL*<F5Q=6ER92!V87)S.PIR97%U:7)E($-A<G`["G)E<75I
M<F4@0V%R<#HZ2&5A=GD["G)E<75I<F4@17)R;F\["G)E<75I<F4@17AP;W)T
M97(Z.DAE879Y.PIR97%U:7)E($5X<&]R=&5R.PIR97%U:7)E($9C;G1L.PIR
M97%U:7)E($9I;&4Z.E1E;7`["G)E<75I<F4@1FEL93HZ4W!E8SL*<F5Q=6ER
M92!84TQO861E<CL*<F5Q=6ER92!#;VYF:6<["G)E<75I<F4@24\Z.DAA;F1L
M93L*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q=6ER92!#;VUP<F5S<SHZ6FQI8CL*
M<F5Q=6ER92!!<F-H:79E.CI::7`["G)E<75I<F4@1&EG97-T.CI32$$["G)E
M<75I<F4@4$%2.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E<75I<F4@4$%2.CI$
M:7-T.PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*<F5Q=6ER92!0
M05(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT.PIR97%U:7)E(&%T=')I8G5T97,[
M"F5V86P@>R!R97%U:7)E($-W9"!].PIE=F%L('L@<F5Q=6ER92!7:6XS,B!]
M.PIE=F%L('L@<F5Q=6ER92!38V%L87(Z.E5T:6P@?3L*979A;"![(')E<75I
M<F4@07)C:&EV93HZ56YZ:7`Z.D)U<G-T('T["F5V86P@>R!R97%U:7)E(%1I
M93HZ2&%S:#HZ3F%M961#87!T=7)E('T["F5V86P@>R!R97%U:7)E(%!E<FQ)
M3SL@<F5Q=6ER92!097)L24\Z.G-C86QA<B!].PIE=F%L('L@<F5Q=6ER92!U
M=&8X('T["GT*<W5B(%]S971?<&%R7W1E;7`@>PII9B`H9&5F:6YE9"`D14Y6
M>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO*2!["B1P
M87)?=&5M<"`]("0Q.PIR971U<FX["GT*9F]R96%C:"!M>2`D<&%T:"`H"BAM
M87`@)$5.5GLD7WTL('%W*"!005)?5$U01$E2(%1-4$1)4B!414U01$E2(%1%
M35`@5$U0("DI+`IQ=R@@0SI<7%1%35`@+W1M<"`N("D**2!["FYE>'0@=6YL
M97-S(&1E9FEN960@)'!A=&@@86YD("UD("1P871H(&%N9"`M=R`D<&%T:#L*
M;7D@)'5S97)N86UE.PIM>2`D<'=U:60["F5V86P@>R@D<'=U:60I(#T@9V5T
M<'=U:60H)#XI(&EF(&1E9FEN960@)#X[?3L*:68@*"!D969I;F5D*"97:6XS
M,CHZ3&]G:6Y.86UE*2`I('L*)'5S97)N86UE(#T@)E=I;C,R.CI,;V=I;DYA
M;64["GT*96QS:68@*&1E9FEN960@)'!W=6ED*2!["B1U<V5R;F%M92`]("1P
M=W5I9#L*?0IE;'-E('L*)'5S97)N86UE(#T@)$5.5GM54T523D%-17T@?'P@
M)$5.5GM54T52?2!\?"`G4UE35$5-)SL*?0HD=7-E<FYA;64@/7X@<R]<5R]?
M+V<["FUY("1S=&UP9&ER(#T@(B1P871H)'-Y<WM?9&5L:6U]<&%R+2(N=6YP
M86-K*")(*B(L("1U<V5R;F%M92D["FUK9&ER("1S=&UP9&ER+"`P-S4U.PII
M9B`H(21%3E9[4$%27T-,14%.?2!A;F0@;7D@)&UT:6UE(#T@*'-T870H)'!R
M;V=N86UE*2E;.5TI('L*;W!E;B!M>2`D9F@L("(\.G)A=R(L("1P<F]G;F%M
M92!O<B!D:64@<7%;0V%N)W0@<F5A9"`B)'!R;V=N86UE(CH@)"%=.PIS965K
M("1F:"P@+3$X+"`R.PIM>2`D8G5F.PIR96%D("1F:"P@)&)U9BP@-CL*:68@
M*"1B=68@97$@(EPP0T%#2$4B*2!["G-E96L@)&9H+"`M-3@L(#(["G)E860@
M)&9H+"`D8G5F+"`T,3L*)&)U9B`]?B!S+UPP+R]G.PHD<W1M<&1I<B`N/2`B
M)'-Y<WM?9&5L:6U]8V%C:&4M)&)U9B(["GT*96QS92!["FUY("1D:6=E<W0@
M/2!E=F%L"GL*<F5Q=6ER92!$:6=E<W0Z.E-(03L*;7D@)&-T>"`]($1I9V5S
M=#HZ4TA!+3YN97<H,2D["F]P96X@;7D@)&9H+"`B/#IR87<B+"`D<')O9VYA
M;64@;W(@9&EE('%Q6T-A;B=T(')E860@(B1P<F]G;F%M92(Z("0A73L*)&-T
M>"T^861D9FEL92@D9F@I.PIC;&]S92@D9F@I.PHD8W1X+3YH97AD:6=E<W0[
M"GT@?'P@)&UT:6UE.PHD<W1M<&1I<B`N/2`B)'-Y<WM?9&5L:6U]8V%C:&4M
M)&1I9V5S="(["GT*8VQO<V4H)&9H*3L*?0IE;'-E('L*)$5.5GM005)?0TQ%
M04Y](#T@,3L*)'-T;7!D:7(@+CT@(B1S>7-[7V1E;&EM?71E;7`M)"0B.PI]
M"B1%3E9[4$%27U1%35!](#T@)'-T;7!D:7(["FUK9&ER("1S=&UP9&ER+"`P
M-S4U.PIL87-T.PI]"B1P87)?=&5M<"`]("0Q(&EF("1%3E9[4$%27U1%35!]
M(&%N9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK*2\["GT*<W5B(%]S879E7V%S
M('L*;7D@*"1N86UE+"`D8V]N=&5N=',L("1M;V1E*2`]($!?.PIM>2`D9G5L
M;&YA;64@/2`B)'!A<E]T96UP+R1N86UE(CL*=6YL97-S("@M92`D9G5L;&YA
M;64I('L*;7D@)'1E;7!N86UE(#T@(B1F=6QL;F%M92XD)"(["F]P96X@;7D@
M)&9H+"`G/CIR87<G+"`D=&5M<&YA;64@;W(@9&EE('%Q6T-A;B=T('=R:71E
M("(D=&5M<&YA;64B.B`D(5T["G!R:6YT("1F:"`D8V]N=&5N=',["F-L;W-E
M("1F:#L*8VAM;V0@)&UO9&4L("1T96UP;F%M92!I9B!D969I;F5D("1M;V1E
M.PIR96YA;64H)'1E;7!N86UE+"`D9G5L;&YA;64I(&]R('5N;&EN:R@D=&5M
M<&YA;64I.PI]"G)E='5R;B`D9G5L;&YA;64["GT*<W5B(%]S971?<')O9VYA
M;64@>PII9B`H9&5F:6YE9"`D14Y6>U!!4E]04D]'3D%-17T@86YD("1%3E9[
M4$%27U!23T=.04U%?2`]?B`O*"XK*2\I('L*)'!R;V=N86UE(#T@)#$["GT*
M)'!R;V=N86UE('Q\/2`D,#L*:68@*"1%3E9[4$%27U1%35!](&%N9"!I;F1E
M>"@D<')O9VYA;64L("1%3E9[4$%27U1%35!]*2`^/2`P*2!["B1P<F]G;F%M
M92`]('-U8G-T<B@D<')O9VYA;64L(')I;F1E>"@D<')O9VYA;64L("1S>7-[
M7V1E;&EM?2D@*R`Q*3L*?0II9B`H(21%3E9[4$%27U!23T=.04U%?2!O<B!I
M;F1E>"@D<')O9VYA;64L("1S>7-[7V1E;&EM?2D@/CT@,"D@>PII9B`H;W!E
M;B!M>2`D9F@L("<\)RP@)'!R;V=N86UE*2!["G)E='5R;B!I9B`M<R`D9F@[
M"GT*:68@*"US("(D<')O9VYA;64D<WES>U]E>&5](BD@>PHD<')O9VYA;64@
M+CT@)'-Y<WM?97AE?3L*<F5T=7)N.PI]"GT*9F]R96%C:"!M>2`D9&ER("AS
M<&QI="`O7%$D<WES>W!A=&A?<V5P?5Q%+RP@)$5.5GM0051(?2D@>PIN97AT
M(&EF(&5X:7-T<R`D14Y6>U!!4E]414U0?2!A;F0@)&1I<B!E<2`D14Y6>U!!
M4E]414U0?3L*)&1I<B`]?B!S+UQ1)'-Y<WM?9&5L:6U]7$4D+R\["B@H)'!R
M;V=N86UE(#T@(B1D:7(D<WES>U]D96QI;7TD<')O9VYA;64D<WES>U]E>&5]
M(BDL(&QA<W0I"FEF("US("(D9&ER)'-Y<WM?9&5L:6U])'!R;V=N86UE)'-Y
M<WM?97AE?2(["B@H)'!R;V=N86UE(#T@(B1D:7(D<WES>U]D96QI;7TD<')O
M9VYA;64B*2P@;&%S="D*:68@+7,@(B1D:7(D<WES>U]D96QI;7TD<')O9VYA
M;64B.PI]"GT*<W5B(%]F:7A?<')O9VYA;64@>PHD,"`]("1P<F]G;F%M92!\
M?#T@)$5.5GM005)?4%)/1TY!345].PII9B`H:6YD97@H)'!R;V=N86UE+"`D
M<WES>U]D96QI;7TI(#P@,"D@>PHD<')O9VYA;64@/2`B+B1S>7-[7V1E;&EM
M?21P<F]G;F%M92(["GT*;7D@)'!W9"`]("AD969I;F5D("9#=V0Z.F=E=&-W
M9"D@/R!#=V0Z.F=E=&-W9"@I"CH@*"AD969I;F5D("97:6XS,CHZ1V5T0W=D
M*2`_(%=I;C,R.CI'971#=V0H*2`Z(&!P=V1@*3L*8VAO;7`H)'!W9"D["B1P
M<F]G;F%M92`]?B!S+UXH/SU<+EPN/UQ1)'-Y<WM?9&5L:6U]7$4I+R1P=V0D
M<WES>U]D96QI;7TO.PHD14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64[
M"GT*<W5B(%]P87)?:6YI=%]E;G8@>PII9B`H("1%3E9[4$%27TE.251)04Q)
M6D5$?2LK(#T](#$@*2!["G)E='5R;CL*?2!E;'-E('L*)$5.5GM005)?24Y)
M5$E!3$E:141](#T@,CL*?0IF;W(@*'%W*"!34$%73D5$(%1%35`@0TQ%04X@
M1$5"54<@0T%#2$4@4%)/1TY!344@*2`I('L*9&5L971E("1%3E9[)U!!4E\G
M+B1??3L*?0IF;W(@*'%W+R!435!$25(@5$5-4"!#3$5!3B!$14)51R`O*2![
M"B1%3E9[)U!!4E\G+B1??2`]("1%3E9[)U!!4E]'3$]"04Q?)RXD7WT@:68@
M97AI<W1S("1%3E9[)U!!4E]'3$]"04Q?)RXD7WT["GT*;7D@)'!A<E]C;&5A
M;B`](")?7T5.5E]005)?0TQ%04Y?7R`@("`@("`@("`@("`@("(["FEF("@D
M14Y6>U!!4E]414U0?2D@>PID96QE=&4@)$5.5GM005)?0TQ%04Y].PI]"F5L
M<VEF("@A97AI<W1S("1%3E9[4$%27T=,3T)!3%]#3$5!3GTI('L*;7D@)'9A
M;'5E(#T@<W5B<W1R*"1P87)?8VQE86XL(#$R("L@;&5N9W1H*")#3$5!3B(I
M*3L*)$5.5GM005)?0TQ%04Y](#T@)#$@:68@)'9A;'5E(#U^("]>4$%27T-,
M14%./2A<4RLI+SL*?0I]"G-U8B!O=71S('L*<F5T=7)N(&EF("1Q=6EE=#L*
M:68@*"1L;V=F:"D@>PIP<FEN="`D;&]G9F@@(D!?7&XB.PI]"F5L<V4@>PIP
M<FEN="`B0%]<;B(["GT*?0IS=6(@:6YI=%]I;F,@>PIR97%U:7)E($-O;F9I
M9SL*<'5S:"!`24Y#+"!G<F5P(&1E9FEN960L(&UA<"`D0V]N9FEG.CI#;VYF
M:6=[)%]]+"!Q=R@*87)C:&QI8F5X<"!P<FEV;&EB97AP('-I=&5A<F-H97AP
M('-I=&5L:6)E>'`*=F5N9&]R87)C:&5X<"!V96YD;W)L:6)E>'`**3L*?0IP
M86-K86=E(&UA:6X["G)E<75I<F4@4$%2.PIU;G-H:69T($!)3D,L(%PF4$%2
M.CIF:6YD7W!A<CL*4$%2+3YI;7!O<G0H0'!A<E]A<F=S*3L*9&EE('%Q6W!A
M<BYP;#H@0V%N)W0@;W!E;B!P97)L('-C<FEP="`B)'!R;V=N86UE(CH@3F\@
M<W5C:"!F:6QE(&]R(&1I<F5C=&]R>5QN70IU;FQE<W,@+64@)'!R;V=N86UE
M.PID;R`D<')O9VYA;64["D-/4D4Z.F5X:70H)#$I(&EF("@D0"`]?B]>7U1+
M7T58251?7"@H7&0K*5PI+RD["F1I92`D0"!I9B`D0#L*?3L*)#HZ7U]%4E)/
M4B`]("1`(&EF("1`.PI]"D-/4D4Z.F5X:70H)#$I(&EF("@D.CI?7T524D]2
M(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("0Z.E]?15)23U(@:68@
M)#HZ7U]%4E)/4CL*,3L*7U]%3D1?7PH`<&5R;'AS:2YC`%]?14Y67U!!4E]#
M3$5!3E]?("`@("`@("`@("`@("`@```[````/@````L````^````$````#X`
M```E````/@```#,````^`````P```#X````&````/@```!0````^````#@``
M`#X````-````/@```"0````^````$@```#X````G````/@````(````^````
M&````#X````)````/@````H````^````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````"1%0``.14```$````H`P``
M`0```#,#```/````?P0```P````-$```#0```$$P```9````S'T!`!L````$
M````&@```-!]`0`<````!````/7^_V\L`0``!0```*0(```&````%`(```H`
M``"=!```"P```!`````5``````````,```#$?@$``@```.`!```4````$0``
M`!<````L#@``$0```$0-```2````Z````!,````(````&`````````#[__]O
M`0``"/K__V\0````````````````````````````````````````````````
M`````````-1]`0```````````!00```4$```%!```!00```4$```%!```!00
M```4$```%!```!00```4$```%!```!00```4$```%!```!00```4$```%!``
M`!00```4$```%!```!00```4$```%!```!00```4$```%!```!00```4$```
M%!```!00```4$```%!```!00```4$```%!```!00```4$```%!```!00```4
M$```%!```!00```4$```%!```!00```4$```%!```!00```4$```%!```!00
M```4$```%!```!00```4$```%!```!00```4$```%!````43````````````
M`$$P``````````````T0````````````````````````````````````````
M````````````@`$`_____XDS``#9,````````+HQ``"S,0``?3,``-`Q``"%
M,P```````&\S``!T,P```````(XS``!'0T,Z("A!;'!I;F4@,3$N,BXQ7V=I
M=#(P,C(P,C$Y*2`Q,2XR+C$@,C`R,C`R,3D`03(```!A96%B:0`!*`````4W
M+4$`!@H'00@!"0(*!!($$P$4`14!%P,8`1H"'`$>!"(!`"YS:'-T<G1A8@`N
M:6YT97)P`"YG;G4N:&%S:``N9'EN<WEM`"YD>6YS='(`+G)E;"YD>6X`+G)E
M;"YP;'0`+FEN:70`+G1E>'0`+F9I;FD`+G)O9&%T80`N96A?9G)A;64`+FEN
M:71?87)R87D`+F9I;FE?87)R87D`+F1Y;F%M:6,`+F=O=``N9&%T80`N8G-S
M`"YC;VUM96YT`"Y!4DTN871T<FEB=71E<P``````````````````````````
M````````````````````````````````"P````$````"````%`$``!0!```8
M```````````````!`````````!,```#V__]O`@```"P!```L`0``Z`````,`
M````````!`````0````=````"P````(````4`@``%`(``)`&```$`````P``
M``0````0````)0````,````"````I`@``*0(``"=!``````````````!````
M`````"T````)`````@```$0-``!$#0``Z`````,`````````!`````@````V
M````"0```$(````L#@``+`X``.`!```#````$`````0````(````/P````$`
M```&````#!````P0```(```````````````"`````````#H````!````!@``
M`!00```4$```\`(`````````````!`````0```!%`````0````8````$$P``
M!!,``#P=``````````````0`````````2P````$````&````0#```$`P```(
M```````````````"`````````%$````!`````@```$@P``!(,```6$``````
M````````!`````````!9`````0````(```"@<```H'````0`````````````
M``0`````````8P````X````#````S'T!`,Q]```$```````````````$````
M!````&\````/`````P```-!]`0#0?0``!```````````````!`````0```![
M````!@````,```#4?0$`U'T``/`````$``````````0````(````A`````$`
M```#````Q'X!`,1^```\`0`````````````$````!````(D````!`````P``
M``"``0``@```/```````````````!`````````"/````"`````,````\@`$`
M/(```"P0``````````````0`````````E`````$````P`````````#R````Q
M```````````````!`````0```)T````#``!P``````````!M@```,P``````
M`````````0`````````!`````P``````````````H(```*T`````````````
)``$`````````
